@@ -2,8 +2,8 @@
                           kileappIface.h  -  description
                              -------------------
     begin                : sam sep 28 2002
-    copyright            : (C) 2002 by Pascal Brachet
-    email                : 
+    copyright            : (C) 2002 - 2003 by Pascal Brachet, 2003 Jeroen Wijnhout
+    email                : Jeroen.Wijnhout@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,13 +21,17 @@
 
 class KileAppDCOPIface : virtual public DCOPObject
 {
-  K_DCOP
+	K_DCOP
 
-  k_dcop:
-    virtual void fileSelected(const QString &url)=0;
-    virtual void projectOpen(const QString &url)=0;
-    virtual void setLine( const QString &line )=0;
-    virtual void setActive()=0;
+	k_dcop:
+		virtual void openDocument(const QString &)=0;
+		virtual void fileSelected(const QString &)=0; //backwards compatibility
+		virtual void closeDocument()=0;
+		virtual void openProject(const QString &)=0;
+		virtual void setLine( const QString &)=0;
+		virtual void setActive()=0;
+		virtual int run(const QString &)=0;
+		virtual int runWith(const QString &, const QString &)=0;
 };
 
 #endif
