@@ -2,8 +2,8 @@
                           tabdialog.h  -  description
                              -------------------
     begin                : Mon Apr 30 2001
-    copyright            : (C) 2001 by Brachet Pascal
-    email                :
+    copyright            : (C) 2001 - 2003 by Brachet Pascal, 2003 Jeroen Wijnhout
+    email                : Jeroen.Wijnhout@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,42 +15,50 @@
  *                                                                         *
  ***************************************************************************/
 
+// dani 17.09.2004: don't override existing rows or columns,  
+//                  when changing the size of the table
+
 #ifndef TABDIALOG_H
 #define TABDIALOG_H
 
-#include <qdialog.h>
+#include "kilewizard.h"
 
 class QTable;
 class QSpinBox;
-class QLabel;
-class QComboBox;
-class QPushButton;
 class QCheckBox;
 
-class tabdialog : public QDialog  {
-    Q_OBJECT
-public:
-    tabdialog(QWidget *parent=0, const char *name=0, const QString &caption = QString::null);
-    ~tabdialog();
+class KComboBox;
+class KConfig;
 
-public:
-    QTable* Table1;
-    QSpinBox *spinBoxRows;
-    QSpinBox *spinBoxCollums;
-    QLabel *QLabel_1;
-    QLabel *QLabel_2;
-    QLabel *QLabel_3;
-    QLabel *QLabel_4;
-    QComboBox *combo1;
-    QComboBox *combo2;
-    QCheckBox* checkbox1;
-    QPushButton *buttonOk;
-    QPushButton *buttonCancel;
-protected slots:
-    void NewRows(int num);
-    void NewCollums(int num);
-};
+namespace KileDialog
+{
+	class QuickTabular : public Wizard
+	{
+		Q_OBJECT
 
+	public:
+		QuickTabular(KConfig *, QWidget *parent=0, const char *name=0, const QString &caption = QString::null);
+		~QuickTabular();
+
+	public slots:
+		void slotOk();
+
+	private:
+		KComboBox	*m_cbAlign, *m_cbSeparator;
+		QSpinBox		*m_spRows, *m_spCols;
+		QCheckBox	*m_ckHSeparator;
+		QTable		*m_table;
+		
+		int m_rows;
+		int m_cols;
+		bool isTableRowEmpty(int row);
+		bool isTableColEmpty(int col);
+		
+	private slots:
+		void slotRowValueChanged(int value);
+		void slotColValueChanged(int value);
+	};
+}
 
 #endif
 
