@@ -2,8 +2,8 @@
                           usermenudialog.cpp  -  description
                              -------------------
     begin                : Sun Jun 3 2001
-    copyright            : (C) 2001 by Brachet Pascal
-    email                :
+    copyright            : (C) 2001 - 2003 by Brachet Pascal, 2003 Jeroen Wijnhout
+    email                : Jeroen.Wijnhout@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -16,17 +16,17 @@
  ***************************************************************************/
 #include "usermenudialog.h"
 
-#include <qcombobox.h>
-#include <qradiobutton.h>
-#include <qbuttongroup.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qlayout.h>
+#include <qcombobox.h>
 #include <qregexp.h>
+#include <qradiobutton.h>
+#include <qbuttongroup.h>
 
-#include <ktextedit.h>
 #include <kpushbutton.h>
 #include <klocale.h>
+#include <ktextedit.h>
 #include <kdebug.h>
 
 namespace KileDialog
